#ifndef UTILS_HH_
#define UTILS_HH_
#include <iostream>
#include <string>
#include <vector>

/** Return the filename of the defintion file of the PSRFITS format. */
inline std::string getPSRFITSdefn(){ 
  return getenv("PSRFITSDEFN"); 

//   std::cerr << "Using local PSRFITS definition! --> $PVO/templates/psrheader_20070209.fits\n"; 
//   return "/DATA/SITAR_1/whi550/VO/PulsarVO/templates/psrheader_20070209.fits"; 
};

std::string removeLeadingBlanks(std::string s);
///< Remove blank spaces from start of a string.

std::string deblank(std::string s);
///< Remove blank spaces from start and end of a string.  
   
std::string charToBinary(char c);
///< Convert a byte to binary representation.

std::string binaryToString(std::vector<bool> v);
///< Convert a bit-wise binary representation to a set of bytes. 

unsigned int * binaryToInt(std::vector<bool> v);
///<Convert a series of bits into a series of bytes in decimal format.

double dmsToDec(std::string input);   
///< Converts a string in the format +12:23:34.45 to a decimal angle in degrees.

std::string decToDMS(double input, int secondPrecision, std::string separator);
///< Converts a decimal into a dd:mm:ss.ss format.

/** Particular instance of decToDMS(double,int,std::string) with
    standard precision & separator */
inline std::string decToDMS(double input){ return decToDMS(input,2,":"); };

std::string getIAUName(double ra, double dec);  
///< Create an IAU-style formatted name, based on the equatorial position.

std::string addDay(std::string date);
///< A function to add a day onto the date.

#endif /*UTILS_HH_*/
